ToolFactory

Trait ToolFactory 

pub trait ToolFactory:
    Debug
    + Send
    + Sync {
    // Required method
    fn add_tools(&self, agent: &mut Agent);
}
Factory for creating the tool set that subagents receive.

Required Methods

fn add_tools(&self, agent: &mut Agent)

Add a fresh set of tools to a new subagent.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors